@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2015-2021 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2015-2022 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -7,6 +7,8 @@
 # bundled with this file.
 #
 
+# Depends: (cp)
+
 =head1 NAME
 
 Chj::xIOUtil - exception-throwing I/O utilities
@@ -32,7 +34,7 @@ use Exporter "import";
 our @EXPORT    = qw();
 our @EXPORT_OK = qw(
     stdin_utf8 stdout_utf8 stderr_utf8 xgetfile_utf8 xputfile_utf8
-    xcopyfile_utf8 xprint_object xcopyfile);
+    xputfile_bytes xcopyfile_utf8 xprint_object xcopyfile);
 our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
 use Chj::xopen ":all";
@@ -91,6 +93,15 @@ sub xputfile_utf8 {
     $out->xclose;
 }
 
+sub xputfile_bytes {
+    @_ == 2 or fp_croak_arity 2;
+    my ($path, $str) = @_;
+    my $out = xopen_write($path);
+    binmode $out or die "binmode";
+    xprint_object($out, $str);
+    $out->xclose;
+}
+
 sub xcopyfile_utf8 {
     @_ == 2 or fp_croak_arity 2;
     my ($src, $dest) = @_;
