@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2003-2014 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2003-2022 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -7,6 +7,8 @@
 # bundled with this file.
 #
 
+# Depends: ()
+
 =head1 NAME
 
 Chj::xoutpipe
@@ -38,13 +40,13 @@ or on the L<website|http://functional-perl.org/>.
 =cut
 
 package Chj::xoutpipe;
-@ISA = 'Exporter';
-require Exporter;
-our @EXPORT = qw(xoutpipe);
 use strict;
 use warnings;
 use warnings FATAL => 'uninitialized';
 use Chj::IO::Command;
+use Exporter 'import';
+
+our @EXPORT = qw(xoutpipe);
 
 sub xoutpipe {
     Chj::IO::Command->new_receiver(@_);
