@@ -13,11 +13,11 @@ FP::Array_sort - 'sensible' sorting setup
 
 =head1 SYNOPSIS
 
-    use FP::Array_sort; # for `array_sort`, `on`, and `cmp_complement`
+    use FP::Array_sort; # for `array_sort` and `on`
 
-    use FP::Ops 'number_cmp'; use FP::Array ':all'; use FP::Equal 'is_equal';
+    use FP::Ops 'real_cmp'; use FP::Array ':all'; use FP::Equal 'is_equal';
     is_equal array_sort([[10, 'a'], [15, 'b'], [-3, 'c']],
-                        on *array_first, \&number_cmp),
+                        on *array_first, \&real_cmp),
              [[-3, 'c'], [10, 'a'], [15, 'b']];
 
 
@@ -34,17 +34,17 @@ Abstracting the repetition of the accessor as a function (`on`) and
 wrapping sort as a higher-order function makes it more
 straight-forward:
 
-    array_sort $ary, on ($foo, \&number_cmp)
+    array_sort $ary, on ($foo, \&real_cmp)
 
 In method interfaces the need becomes more obvious: if $ary is one of
 the FP sequences (FP::PureArray, FP::List, FP::StrictList, FP::Stream)
 that supports `sort` (TODO) then:
 
-    $s->sort (on $foo, \&number_cmp)
+    $s->sort (on $foo, \&real_cmp)
 
 or if the comparison function already exists:
 
-    $numbers->sort (\&number_cmp)
+    $numbers->sort (\&real_cmp)
 
 =head1 SEE ALSO
 
@@ -57,7 +57,7 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-# XX Should `on` (and `cmp_complement`?) be moved to `FP::Combinators`?
+# XX Should `on` be moved to `FP::Combinators`?
 
 package FP::Array_sort;
 use strict;
@@ -65,13 +65,13 @@ use warnings;
 use warnings FATAL => 'uninitialized';
 use Exporter "import";
 
-our @EXPORT      = qw(array_sort array_sortCompare on on_maybe cmp_complement);
+our @EXPORT      = qw(array_sort array_sortCompare on on_maybe);
 our @EXPORT_OK   = qw();
 our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
-use FP::Ops qw(string_cmp number_cmp binary_operator);
-use Chj::TEST;
 use FP::Carp;
+use Chj::TEST;
+use FP::Ops qw(real_cmp);    # for pod snippets, only, right?
 
 sub array_sort {
     @_ == 1 or @_ == 2 or fp_croak_arity "1 or 2";
@@ -111,28 +111,4 @@ sub on_maybe {
     defined $maybe_select ? on($maybe_select, $cmp) : $cmp
 }
 
-# see also `complement` from FP::Predicates
-sub cmp_complement {
-    @_ == 1 or fp_croak_arity 1;
-    my ($cmp) = @_;
-    sub {
-        -&$cmp(@_)
-    }
-}
-
-TEST {
-    my $f = cmp_complement binary_operator "cmp";
-    [
-        map { &$f(@$_) } (
-            [2,     4],
-            [4,     2],
-            [3,     3],
-            ["abc", "bbc"],
-            ["ab",  "ab"],
-            ["bbc", "abc"]
-        )
-    ]
-}
-[1, -1, 0, 1, 0, -1];
-
 1
