@@ -93,7 +93,7 @@ sub package_is_populated {
 }
 
 sub require_package {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($package) = @_;
     if (not package_is_populated $package) {
         $package =~ s|::|/|g;
@@ -103,7 +103,7 @@ sub require_package {
 }
 
 sub package_check_possible_interface {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($caller, $possible_interface_package) = @_;
     if (my $m = $possible_interface_package->can("FP_Interface__method_names"))
     {
@@ -125,7 +125,7 @@ sub package_check_possible_interface {
 }
 
 sub implemented_with_caller {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($caller, $interface) = @_;
     my ($caller_package, $caller_file, $caller_line) = @$caller;
     require_package $interface;
