@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2015-2020 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2015-2021 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -186,7 +186,7 @@ sub fixn {
     # weaken $_ for @ff;
     # ^ XXX: releases too early, same issue as
     #   mentioned in `intro/more_tailcalls`
-    wantarray ? @ff_ : do {
+    wantarray ? @ff_ : do {    ## no critic
         @ff == 1 or die "fixn: got multiple arguments, but scalar context";
         $ff_[0]
     }
