@@ -24,23 +24,26 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package PXML::Serialize::t;
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
 
 use Chj::TEST;
 use PXML::Serialize qw(pxml_print_fragment_fast);
 use PXML::XHTML ":all";
 use PXML qw(pxmlflush);
 
-TEST_STDOUT { pxml_print_fragment_fast ["abc",P(2)], *STDOUT }
-  'abc<p>2</p>';
+TEST_STDOUT { pxml_print_fragment_fast ["abc", P(2)], *STDOUT }
+'abc<p>2</p>';
 TEST_STDOUT { pxml_print_fragment_fast ["abc"], *STDOUT }
-  'abc';
+'abc';
 
-TEST_STDOUT { pxml_print_fragment_fast P({foo=> ["a",["b", pxmlflush, "c"], "d"]},
-                                         "abc"), *STDOUT{IO} }
-  '<p foo="abcd">abc</p>';
+TEST_STDOUT {
+    pxml_print_fragment_fast P({ foo => ["a", ["b", pxmlflush, "c"], "d"] },
+        "abc"), *STDOUT{IO}
+}
+'<p foo="abcd">abc</p>';
 
 1
